translate.storage.csvl10n.csvunit

Package translate :: Package storage :: Module csvl10n :: Class csvunit |
[hide private]
[frames] | no frames]

# Class csvunit

source code

Instance Methods | [hide private]
__init__(self, source=None) Constructs a TranslationUnit containing the given source string. | source code
add_spreadsheet_escapes(self, source, target) add common spreadsheet escapes to two strings | source code
remove_spreadsheet_escapes(self, source, target) remove common spreadsheet escapes from two strings | source code
fromdict(self, cedict) | source code
todict(self, encoding='utf-8') | source code
Inherited from `base.TranslationUnit`: `__eq__`, `__str__`, `get_state_id`, `get_state_n`, `getcontext`, `getid`, `getunits`, `hasplural`, `infer_state`, `isblank`, `isfuzzy`, `isheader`, `isobsolete`, `isreview`, `istranslatable`, `istranslated`, `makeobsolete`, `markfuzzy`, `markreviewneeded`, `merge`, `multistring_to_rich`, `set_state_n`, `setcontext`, `setid`, `unit_iter` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`
Source
Inherited from `base.TranslationUnit`: `getsourcelanguage`, `setsource` Inherited from `base.TranslationUnit` (private): `_get_rich_source`, `_set_rich_source`
Target
Inherited from `base.TranslationUnit`: `gettargetlanguage`, `gettargetlen`, `settarget` Inherited from `base.TranslationUnit` (private): `_get_rich_target`, `_set_rich_target`
Notes
Inherited from `base.TranslationUnit`: `addnote`, `getnotes`, `removenotes`
Locations
Inherited from `base.TranslationUnit`: `addlocation`, `addlocations`, `getlocations`
Errors
Inherited from `base.TranslationUnit`: `adderror`, `geterrors`

Class Methods | [hide private]
Inherited from `base.TranslationUnit`: `buildfromunit`, `rich_to_multistring`

Class Variables | [hide private]
| spreadsheetescapes = `[("+", "\\+"), ("-", "\\-"), ("=", "\\=")`...``
Inherited from `base.TranslationUnit`: `STATE`, `S_EMPTY`, `S_FINAL`, `S_NEEDS_REVIEW`, `S_NEEDS_WORK`, `S_OBSOLETE`, `S_REJECTED`, `S_UNREVIEWED`, `rich_parsers`

Properties | [hide private]
Inherited from `base.TranslationUnit`: `rid`, `xid` Inherited from `object`: `__class__`
Source
Inherited from `base.TranslationUnit`: `rich_source`, `source`
Target
Inherited from `base.TranslationUnit`: `rich_target`, `target`

Method Details | [hide private]

### __init__(self, source=None) (Constructor) | source code
Constructs a TranslationUnit containing the given source string. Overrides: object.__init__ (inherited documentation)

Class Variable Details | [hide private]

  ### spreadsheetescapes Value:
      [("+", "\\+"), ("-", "\\-"), ("=", "\\="), ("'", "\\'")]